parsedatetime.tests.TestErrors

Package parsedatetime :: Package tests :: Module TestErrors |
[hide private]
[frames] | no frames]

# Source Code for Module parsedatetime.tests.TestErrors

     1  #!/usr/bin/env python
     2
     3  """
     4  Test parsing of units
     5  """
     6
     7  import unittest, time, datetime
     8  import parsedatetime.parsedatetime as pt
     9
    10
    11    # a special compare function is used to allow us to ignore the seconds as
    12    # the running of the test could cross a minute boundary
    13 -def _compareResults(result, check):
    14      target, t_flag = result
    15      value,  v_flag = check
    16
    17      t_yr, t_mth, t_dy, t_hr, t_min, _, _, _, _ = target
    18      v_yr, v_mth, v_dy, v_hr, v_min, _, _, _, _ = value
    19
    20      return ((t_yr == v_yr) and (t_mth == v_mth) and (t_dy == v_dy) and
    21              (t_hr == v_hr) and (t_min == v_min)) and (t_flag == v_flag)
    22
    23 -class test(unittest.TestCase):
    24 -    def setUp(self):
    25          self.cal = pt.Calendar()
    26          self.yr, self.mth, self.dy, self.hr, self.mn, self.sec, self.wd, self.yd, self.isdst = time.localtime()
    27
    28 -    def testErrors(self):
    29          s     = datetime.datetime.now()
    30          start = s.timetuple()
    31
    32          self.assertTrue(_compareResults(self.cal.parse('01/0',   start), (start, 0)))
    33          self.assertTrue(_compareResults(self.cal.parse('08/35',  start), (start, 0)))
    34          self.assertTrue(_compareResults(self.cal.parse('18/35',  start), (start, 0)))
    35          self.assertTrue(_compareResults(self.cal.parse('1799',   start), (start, 0)))
    36          self.assertTrue(_compareResults(self.cal.parse('781',    start), (start, 0)))
    37          self.assertTrue(_compareResults(self.cal.parse('2702',   start), (start, 0)))
    38          self.assertTrue(_compareResults(self.cal.parse('78',     start), (start, 0)))
    39          self.assertTrue(_compareResults(self.cal.parse('11',     start), (start, 0)))
    40          self.assertTrue(_compareResults(self.cal.parse('1',      start), (start, 0)))
    41          self.assertTrue(_compareResults(self.cal.parse('174565', start), (start, 0)))
    42          self.assertTrue(_compareResults(self.cal.parse('177505', start), (start, 0)))
    43
    44
    45  if __name__ == "__main__":
    46      unittest.main()
    47